@@ -19,7 +19,7 @@ from typing_extensions import Annotated, get_args, get_origin
 from strawberry.annotation import StrawberryAnnotation
 from strawberry.custom_scalar import ScalarDefinition, ScalarWrapper
 from strawberry.enum import EnumDefinition
-from strawberry.lazy_type import LazyType
+from strawberry.lazy_type import LazyType, StrawberryLazyReference
 from strawberry.type import StrawberryList, StrawberryOptional, StrawberryType
 
 from .exceptions import MultipleStrawberryArgumentsError, UnsupportedTypeError
@@ -106,6 +106,7 @@ class StrawberryArgument:
         # in the other Annotated args, raising an exception if there
         # are multiple StrawberryArgumentAnnotations
         argument_annotation_seen = False
+
         for arg in annotated_args[1:]:
             if isinstance(arg, StrawberryArgumentAnnotation):
                 if argument_annotation_seen:
@@ -120,6 +121,11 @@ class StrawberryArgument:
                 self.deprecation_reason = arg.deprecation_reason
                 self.directives = arg.directives
 
+            if isinstance(arg, StrawberryLazyReference):
+                self.type_annotation = StrawberryAnnotation(
+                    arg.resolve_forward_ref(annotated_args[0])
+                )
+
 
 def convert_argument(
     value: object,
