@@ -38,7 +38,10 @@ def _impl_type(
 
     directives = list(directives)
 
-    directives.extend(Key(key, UNSET) if isinstance(key, str) else key for key in keys)
+    directives.extend(
+        Key(fields=key, resolvable=UNSET) if isinstance(key, str) else key
+        for key in keys
+    )
 
     if shareable:
         directives.append(Shareable())
@@ -47,7 +50,7 @@ def _impl_type(
         directives.append(Inaccessible())
 
     if tags:
-        directives.extend(Tag(tag) for tag in tags)
+        directives.extend(Tag(name=tag) for tag in tags)
 
     return base_type(
         cls,
